@echo off
REM Build script for DODS under win32

REM What is the current directory ?  Build Dods there and dump
REM logfile there also.
set batpath=%~p0
set batlog=%batpath%log.txt
set batdods=%batpath%DODS

echo "Starting build of DODS" >%batlog%

REM Scratch any pre-existing dods distribution
echo "Deleting files from previous build"
cd %batpath%
rd /S /Q DODS >>%batlog% && echo "Previous build deleted"

REM ------ Start Configuration Section -----------------------------
set buildVCPP=7
set ynMailResults=N
REM set smtpServer=""
REM set notifyTo=""

REM Uncomment the following line to run non-interactively with the above
REM defaults.  Change buildVCPP to 6 if building with VC++ 6.0.
goto endConfig

:askCompiler
REM Query for VC++ version that we're going to build with
echo "What compiler will you be building with ? [6 | 7 | Q]"
set /P buildVCPP="? "
if "%buildVCPP%"=="6" echo "Building for VC++ 6.0" && goto askNotify
if "%buildVCPP%"=="7" echo "Building for VC++ 7.x" && goto askNotify
if "%buildVCPP%"=="Q" exit
echo "Unsupported win32 compiler specified, try again"
goto askCompiler

:askNotify
REM See if we want to notify anybody of the build results
echo "Do you want to email results to anyone ? [Y | N | Q]"
set /P ynMailResults="? "
if "%ynMailResults%"=="N" goto endConfig
if "%ynMailResults%"=="Y" goto askMailServer
if "%ynMailResults%"=="Q" exit
echo "Invalid Response, try again"
goto askNotify

:askMailServer
echo "What mail server will be used to notify of results ? [<valid smtp server> | Q]"
set /P smtpServer="? "
if "%smtpServer%"=="" echo "You must specify the mail server" && goto askMailServer
if "%smtpServer%"=="Q" exit

:askNotifyWho
echo "Notify what email address(es) build results ? [<email address[, email address]> | Q]"
set /P notifyTo="? "
if "%notifyTo%"=="" echo "Must specify one or more email addresses" && goto askNotifyWho
if "%notifyTo%"=="Q" exit

REM Configure blatt
blat -install "%smtpServer%" "%notifyTo%" >>%batlog%

REM ------ End Configuration Section -------------------------------

:endConfig

cd %batpath%

echo "Querying CVS ... please wait" >>%batlog%
REM As of 12/2003,  The entire distribution comes from the release3-4 branch,
REM except for the matlab toolbox - which comes from the trunk.
cvs -Q -f -d :pserver:anonymous@dodsdev.gso.uri.edu:/usr/local/cvs-repository co -r release-3-4 "DODS" >>%batlog%
rd /S /Q "DOD/src/clients/ml-toolbox"
cvs -Q -f -d :pserver:anonymous@dodsdev.gso.uri.edu:/usr/local/cvs-repository co "DODS/src/clients/ml-toolbox" >>%batlog%
cd %batdods% || goto baterror

REM Copy the 'pthread' and 'CppUnit' libraries and Headers into the distribution.
echo Copying the pthreads and CppUnit libraries and headers >>%batlog%
md lib
md bin
md include\pthreads
md include\cppunit\extensions
md include\cppunit\ui\mfc
md include\cppunit\ui\qt
md include\cppunit\ui\text
REM Pthread and CppUnit libraries are all in C:\dodstools\lib
copy /Y C:\dodstools\lib\*.lib lib\ >>%batlog% || goto baterror
copy /Y C:\dodstools\bin\*.dll bin\ >>%batlog% || goto baterror
copy /Y C:\dodstools\include\pthreads\*.* include\pthreads\ >>%batlog% || goto baterror
copy /Y C:\dodstools\include\cppunit\*.* include\cppunit\ >>%batlog% || goto baterror
copy /Y C:\dodstools\include\cppunit\extensions\*.* include\cppunit\extensions\ >>%batlog% || goto baterror
copy /Y C:\dodstools\include\cppunit\ui\mfc\*.* include\cppunit\ui\mfc\ >>%batlog% || goto baterror
copy /Y C:\dodstools\include\cppunit\ui\qt\*.* include\cppunit\ui\qt\ >>%batlog% || goto baterror
copy /Y C:\dodstools\include\cppunit\ui\text\*.* include\cppunit\ui\text\ >>%batlog% || goto baterror

@echo on

echo Building the 3rd-party packages >>%batlog%
cd src\packages\win32Dods >>%batlog% || goto baterror
nmake >>%batlog% || goto baterror
cd %batdods% || goto baterror

echo Building Dods Core >>%batlog%
cd src\dap\win32 >>%batlog% || goto baterror
REM VC++ 6 & 7 need different mangled names
if "%buildVCPP%"=="6" ( copy /Y libdapVCPP6.def libdap.def )
if "%buildVCPP%"=="7" ( copy /Y libdapVCPP7.def libdap.def )
nmake grammarclean >>%batlog% || goto baterror
nmake all >>%batlog% || goto baterror
nmake install >>%batlog% || goto baterror
cd %batdods% || goto baterror

echo Building the netcdf client-side library >>%batlog%
cd src\nc3-dods\win32 >>%batlog% || goto baterror
nmake all >>%batlog% || goto baterror
nmake install >>%batlog% || goto baterror
cd %batdods% || goto baterror

echo Building the Freeform libraries >>%batlog%
cd src\ff-dods\FFND\win32 >>%batlog% || goto baterror
nmake all >>%batlog% || goto baterror
nmake install >>%batlog% || goto baterror
cd %batdods% || goto baterror

echo Building the Freeform Servers >>%batlog%
cd src\ff-dods\win32 >>%batlog% || goto baterror
nmake all >>%batlog% || goto baterror
nmake install >>%batlog% || goto baterror
cd %batdods% || goto baterror

echo Building the Matlab command-line client >>%batlog%
cd src\clients\ml-cmdln\win32 >>%batlog% || goto baterror
nmake >>%batlog% || goto baterror
nmake install >>%batlog% || goto baterror
cd %batdods% || goto baterror

echo Building the idl command-line client >>%batlog%
cd src\clients\idl-cmdln\win32 >>%batlog% || goto baterror
nmake >>%batlog% || goto baterror
nmake install >>%batlog% || goto baterror
cd %batdods% || goto baterror

echo Building the matlab toolbox >>%batlog%
cd src\clients\ml-toolbox\win32 >>%batlog% || goto baterror
nmake install >>%batlog% || goto baterror
cd %batdods% || goto baterror

:batsuccess
echo SUCCESS building Dods for Win32 >>%batlog%
cd %batpath%
echo win32 distribution build succeeded >>%batlog%
if "%ynMailResults%"=="N" exit
blat %batlog% -to "%notifyTo%" -subject "SUCCESS: Win32 distribution built successfully"
exit

:baterror
echo FAILURE building Dods for win32 >>%batlog%
cd %batpath%
echo win32 distribution build failed >>%batlog%
if "%ynMailResults%"=="N" exit
blat %batlog% -to "%notifyTo%" -subject "WARNING: Win32 distibution failed to build"
exit
